@@ -9,15 +9,12 @@
 
 
 
-/* $Header: /cvsroot/bibletime/bibletime/bibletime/backend/bt_plainhtml.h,v 1.2 2006/09/20 17:11:36 mgruner Exp $ */
-/* $Revision: 1.2 $ */
+/* $Header: /cvsroot/bibletime/bibletime/bibletime/backend/bt_plainhtml.h,v 1.3 2007/06/29 22:47:14 joachim Exp $ */
+/* $Revision: 1.3 $ */
 
 #ifndef BT_PLAINHTML_H
 #define BT_PLAINHTML_H
 
-//Backend
-#include "cfiltertool.h"
-
 //Sword includes
 #include <swkey.h>
 #include <swmodule.h>
