@@ -48,7 +48,7 @@
  * @endcode
  *
   * @author The BibleTime team
-  * @version $Id: cswordldkey.h,v 1.24 2006/02/25 11:38:15 joachim Exp $
+  * @version $Id: cswordldkey.h,v 1.25 2007/10/26 18:26:23 jerickson314 Exp $
   */
 
 class CSwordLDKey : public CSwordKey, public sword::SWKey {
@@ -98,6 +98,11 @@ public:
 	* Assignment operator for more ease of use of this class. 
 	*/
 	virtual CSwordLDKey& operator = (const QString& keyname );
+protected:
+	/**
+	 * The raw key for direct use with Sword.
+	 */
+	virtual const char * rawKey() const;
 };
 
 
