@@ -16,6 +16,7 @@
 //Qt includes
 #include <qfile.h>
 #include <qdatastream.h>
+#include <qtextcodec.h>
 
 //Sword includes
 #include <swmodule.h>
@@ -30,14 +31,6 @@
 //systems rebuild their caches
 #define CACHE_FORMAT "2"
 
-// class myLocaleAwareCompare {
-// public:
-//  int operator() (const QString& s1, const QString& s2) {
-// //  qWarning("using own operator<()");
-//    return s1.localeAwareCompare(s2);
-//   }
-//  };
-
 CSwordLexiconModuleInfo::CSwordLexiconModuleInfo( sword::SWModule* module, CSwordBackend* const backend ) : CSwordModuleInfo(module, backend) {
 	m_entryList = 0;
 }
@@ -72,8 +65,8 @@ QStringList* const CSwordLexiconModuleInfo::entries() {
 
 		//Check for buggy modules! They will not be loaded any more.
 
-		if ( name() == QString("ZhEnglish") && QString( config( CSwordModuleInfo::ModuleVersion ) ) == QString("0.5") ) {
-			qWarning("Module ZhEnglish (Version 0.5) is buggy and will not be loaded. Please install a newer version.");
+		if ( name() == QString("ZhEnglish")) {
+			qWarning("Module ZhEnglish is buggy and will not be loaded.");
 			return m_entryList;
 		}
 
@@ -116,7 +109,9 @@ QStringList* const CSwordLexiconModuleInfo::entries() {
 				}
 				else { //for latin1 modules use fromLatin1 because of speed
 					//           m_entryList->append(QString::fromLatin1(my_module->KeyText()));
-					m_entryList->append(QString(my_module->KeyText()));
+					
+					QTextCodec *codec = QTextCodec::codecForName("CP1252");
+					m_entryList->append(codec->toUnicode(my_module->KeyText()));
 				}
 
 				(*my_module)++;
