@@ -43,7 +43,7 @@ namespace Rendering {
  * does inherit from this class.
  *
  * @author The BibleTime team
- * @version $Id: cswordmoduleinfo.h,v 1.81 2006/04/13 23:14:17 joachim Exp $
+ * @version $Id: cswordmoduleinfo.h,v 1.83 2007/02/04 23:12:32 joachim Exp $
  */
 
 class CSwordModuleInfo {
@@ -214,7 +214,7 @@ public:
 	virtual const QString getModuleStandardIndexLocation() const;
 	/**
 	* Builds a search index for this module
-   */
+  	*/
 	virtual void buildIndex();
 	/**
 	* Returns index size
@@ -322,13 +322,6 @@ private:
 	sword::SWModule* m_module;
 	sword::ListKey m_searchResult;
 
-	// conversion buffers for wide char <-> utf8
-	enum {
-		LUCENE_MAX_FIELD_LENGTH = 20000
-	};
-	//wchar_t m_wcharBuffer[MAX_CONV_SIZE + 1];
-	//char m_utfBuffer[MAX_CONV_SIZE + 1];
-
 	mutable struct DataCache {
 		DataCache() {
 			language = 0;
