@@ -40,7 +40,7 @@
  * Call the constructor only with a valid verse based modules, otherwise this key will be invalid
  * and the application will probably crash.
  *
- * @version $Id: cswordversekey.h,v 1.26 2006/02/25 11:38:15 joachim Exp $
+ * @version $Id: cswordversekey.h,v 1.27 2007/10/26 18:26:23 jerickson314 Exp $
  * @short CSwordKey implementation for Sword's VerseKey.
  * @author The BibleTime team
  */
@@ -112,6 +112,11 @@ public:
 	* Assignment operator for more ease of use.
 	*/
 	virtual CSwordVerseKey& operator = (const QString& keyname);
+protected:
+	/**
+	 * Returns the raw key for use with Sword.
+	 */
+	virtual const char * rawKey() const;
 };
 
 #endif
