@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //local includes
 #include "config.h"
@@ -12,7 +21,6 @@
 #include "frontend/displaywindow/creadwindow.h"
 #include "frontend/displaywindow/cwritewindow.h"
 #include "frontend/keychooser/ckeychooser.h"
-//#include "frontend/cprinter.h"
 #include "frontend/cbtconfig.h"
 
 #include "util/ctoolclass.h"
@@ -43,6 +51,8 @@
 #include <ktoolbar.h>
 #include <krandomsequence.h>
 
+using namespace Profile;
+
 BibleTime::BibleTime()
 : BibleTimeInterface("BibleTimeInterface"),
 #if KDE_VERSION >= 0x030200
@@ -60,13 +70,11 @@ m_leftPaneSplitter(0),
 m_mdi(0),
 m_profileMgr(),
 m_backend(0),
-m_printer(0),
 m_mainIndex(0) {
 	setObjId("BibleTimeInterface");
 	setHelpMenuEnabled(false);
 
 	initBackends();
-	initPrinter();
 	initView();
 	initActions();
 
