@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "bibletimeapp.h"
 
@@ -16,13 +25,11 @@ BibleTimeApp::BibleTimeApp() {
 }
 
 BibleTimeApp::~BibleTimeApp() {
-	//we can set this safely now because we close now (hopyfully without crash)
-	CBTConfig::set
-		(CBTConfig::crashedLastTime, false);
-	CBTConfig::set
-		(CBTConfig::crashedTwoTimes, false);
 
-	deletePrinter();
+	//we can set this safely now because we close now (hopyfully without crash)
+	CBTConfig::set(CBTConfig::crashedLastTime, false);
+	CBTConfig::set(CBTConfig::crashedTwoTimes, false);
+
 	deleteDisplayTemplateMgr();
 	deleteLanguageMgr();
 	deleteBackend();
