@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef BIBLETIME_INTERFACE_H
 #define BIBLETIME_INTERFACE_H
@@ -43,6 +52,9 @@ k_dcop:
 	* @param key The key which is set to all Bible and Commentary windows.
 	*/
 	virtual void syncAllVerseBasedModules(const QString& key) = 0;
+	/** Reload all modules
+	*/
+	virtual void reloadModules() = 0;
 	/** Open a new read window for the module moduleName using the given key
 	* @param moduleName The name of the module which is opened in a new module window.
 	* @param key The key to set to the newly opened window.
