@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CPROFILEMGR_H
 #define CPROFILEMGR_H
@@ -8,11 +17,11 @@
 //Qt includes
 #include <qstring.h>
 
+namespace Profile {
 /** The manager for profiles.
  * Provides functions to create, delete, save and load profiles.
-  * @author The BibleTime team
-  */
-
+ * @author The BibleTime team
+ */
 class CProfileMgr {
 public:
 	CProfileMgr();
@@ -55,4 +64,6 @@ protected:
 	CProfile* m_startupProfile;
 };
 
+} //end of namespace Profile
+
 #endif
