@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "cswordsetupmodulelistview.h"
 #include "btinstallmgr.h"
@@ -18,7 +27,7 @@
 
 using namespace sword;
 
-namespace InstallationManager {
+namespace BookshelfManager {
 
     /** Tooltip implementation for QListView widgets.
      * @short Tooltip for InstallationManager listviews
@@ -59,7 +68,7 @@ namespace InstallationManager {
     CSwordSetupModuleListView::CSwordSetupModuleListView(QWidget *parent, bool is_remote, sword::InstallSource* installSource)
             : KListView(parent), m_is_remote( is_remote ) {
         Q_ASSERT(installSource);
-        new InstallationManager::ToolTip(this);
+        new BookshelfManager::ToolTip(this);
         m_backend = installSource ? BTInstallMgr::Tool::backend(installSource) : CPointers::backend();
 
         addColumn(i18n("Name"));
