@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CDISPLAYWINDOW_H
 #define CDISPLAYWINDOW_H
@@ -13,6 +22,8 @@
 #include "backend/cswordtreekey.h"
 #include "backend/cswordldkey.h"
 
+#include "frontend/cprofilewindow.h"
+
 //Qt includes
 #include <qwidget.h>
 
@@ -20,17 +31,17 @@
 #include <kmainwindow.h>
 
 
+//Forward declarations
 class CMDIArea;
 class CReadWindow;
 class CWriteWindow;
 class CMDIArea;
-class CProfileWindow;
-class KAccel;
 class CDisplaySettingsButton;
 class CDisplay;
 class CKeyChooser;
 class CModuleChooserBar;
 class CDisplaySettingsButton;
+class KAccel;
 class KToolBar;
 class KPopupMenu;
 
@@ -66,11 +77,11 @@ public:
 	/**
 	* Store the settings of this window in the given CProfileWindow object.
 	*/
-	virtual void storeProfileSettings( CProfileWindow* profileWindow ) = 0;
+	virtual void storeProfileSettings( Profile::CProfileWindow* profileWindow ) = 0;
 	/**
 	* Store the settings of this window in the given profile window.
 	*/
-	virtual void applyProfileSettings( CProfileWindow* profileWindow ) = 0;
+	virtual void applyProfileSettings( Profile::CProfileWindow* profileWindow ) = 0;
 	/**
 	* Set the window caption.
 	*/
@@ -124,9 +135,20 @@ public:
 	*/
 	void setMainToolBar( KToolBar* bar );
 	/**
+	* Sets the buttons toolbar.
+	*/
+	void setButtonsToolBar( KToolBar* bar );
+	/**
 	* Returns the main toolbar.
 	*/
 	KToolBar* const mainToolBar() const;
+	/**
+	* Returns the buttons toolbar.
+	*/
+	KToolBar* const buttonsToolBar() const;
+	/**
+	* Initialize the toolbars
+	*/
 	virtual void initToolbars() = 0;
 	/**
 	* Returns the display settings button
@@ -146,7 +168,7 @@ public:
 	*/
 	virtual void setDisplayWidget( CDisplay* newDisplay );
 
-	/* Returns whether syncs to the active window are allowed at this time for this display window
+	/** Returns whether syncs to the active window are allowed at this time for this display window
 	* @return boolean value whether sync is allowed
 	*/
 	virtual const bool syncAllowed() const {
@@ -226,6 +248,10 @@ protected slots:
 
 	void slotSearchInModules();
 
+	void printAll();
+	void printAnchorWithText();
+
+
 private:
 	CMDIArea* m_mdi;
 
@@ -234,12 +260,14 @@ private:
 
 	CSwordBackend::FilterOptions m_filterOptions;
 	CSwordBackend::DisplayOptions m_displayOptions;
+
 	CDisplaySettingsButton* m_displaySettingsButton;
 	CKeyChooser* m_keyChooser;
 	CSwordKey* m_swordKey;
 	bool m_isReady;
 	CModuleChooserBar* m_moduleChooserBar;
 	KToolBar* m_mainToolBar;
+	KToolBar* m_buttonsToolBar;
 	KPopupMenu* m_popupMenu;
 	CDisplay* m_displayWidget;
 };
