@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "chtmlwritewindow.h"
 
@@ -14,6 +23,7 @@
 #include <kaction.h>
 #include <klocale.h>
 
+using namespace Profile;
 
 CHTMLWriteWindow::CHTMLWriteWindow(ListCSwordModuleInfo modules, CMDIArea* parent, const char *name)
 : CPlainWriteWindow(modules, parent, name) {}
