@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CPLAINWRITEWINDOW_H
 #define CPLAINWRITEWINDOW_H
@@ -25,11 +34,11 @@ public:
 	/**
 	* Store the settings of this window in the given CProfileWindow object.
 	*/
-	virtual void storeProfileSettings( CProfileWindow* profileWindow );
+	virtual void storeProfileSettings( Profile::CProfileWindow* profileWindow );
 	/**
 	* Store the settings of this window in the given profile window.
 	*/
-	virtual void applyProfileSettings( CProfileWindow* profileWindow );
+	virtual void applyProfileSettings( Profile::CProfileWindow* profileWindow );
 
 	/**
 	 * Setups the popup menu of this display widget.
