@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CWRITEWINDOW_H
 #define CWRITEWINDOW_H
@@ -24,11 +33,11 @@ public:
 	/**
 	* Store the settings of this window in the given CProfileWindow object.
 	*/
-	virtual void storeProfileSettings(CProfileWindow * const settings);
+	virtual void storeProfileSettings(Profile::CProfileWindow * const settings);
 	/**
 	* Store the settings of this window in the given CProfileWindow object.
 	*/
-	virtual void applyProfileSettings(CProfileWindow * const settings);
+	virtual void applyProfileSettings(Profile::CProfileWindow * const settings);
 	/**
 	* Returns the write display widget used by this window.
 	*/
