@@ -132,81 +132,7 @@ private:
 	CSwordModuleSearch m_searcher;
 };
 
-	namespace Options {
-class CModuleChooser : public KListView, public CPointers {
-	Q_OBJECT
-public:
-class ModuleCheckBoxItem : virtual public QCheckListItem {
-public:
-		ModuleCheckBoxItem(QListViewItem* item, CSwordModuleInfo* module);
-		~ModuleCheckBoxItem();
-		/**
-		* Returns the used module.
-		*/
-		CSwordModuleInfo* const module() const;
-private:
-		CSwordModuleInfo* m_module;
-	};
 
-	CModuleChooser(QWidget* parent);
-	~CModuleChooser();
-	/**
-	* Sets the list of modules and updates the state of the checkbox items.
-	*/
-	void setModules( ListCSwordModuleInfo modules );
-	/**
-	* Returns a list of selected modules.
-	*/
-	ListCSwordModuleInfo modules();
-
-public slots:
-	/**
-	* Reimplemented to open the folders which contain checked module items
-	*/
-	virtual void show();
-
-
-protected: // Protected methods
-	/**
-	* Initializes this widget and the childs of it.
-	*/
-	void initView();
-	/**
-	* Initializes the tree of this widget.
-	*/
-	void initTree();
-};
-
-class CModuleChooserDialog : public KDialogBase  {
-	Q_OBJECT
-public:
-	CModuleChooserDialog(QWidget* parentDialog, ListCSwordModuleInfo modules);
-	~CModuleChooserDialog();
-
-signals:
-	void modulesChanged(ListCSwordModuleInfo modules);
-
-protected: // Protected methods
-	/**
-	* Initializes the view of this dialog
-	*/
-	void initView();
-	/**
-	* Initializes the connections of this dialog.
-	*/
-	void initConnections();
-
-protected slots: // Protected slots
-	/**
-	* Reimplementation to handle the modules.
-	*/
-	virtual void slotOk();
-
-private:
-	Options::CModuleChooser* m_moduleChooser;
-};
-
-	} //end of namespace Search::Options
 } //end of namespace Search
 
 #endif
