@@ -9,8 +9,8 @@
 
 
 
-/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.143 2007/04/02 21:53:48 joachim Exp $ */
-/* $Revision: 1.143 $ */
+/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.144 2007/10/26 21:19:27 eelik Exp $ */
+/* $Revision: 1.144 $ */
 
 //standard includes
 #include <stdlib.h>
@@ -245,7 +245,16 @@ int main(int argc, char* argv[]) {
 
 	if (kapp->isRestored()) {
 		//    qWarning("Restoring BibleTime");
-		RESTORE( BibleTime );
+		//RESTORE( BibleTime );
+		int n = 1;
+		while (KMainWindow::canBeRestored(n)){
+			if (KMainWindow::classNameOfToplevel(n) == QString("BibleTime")) {
+				bibletime_ptr = new BibleTime;
+				bibletime_ptr->restore(n);
+			}
+			n++;
+   		}
+		bibletime_ptr->restoreWorkspace();
 	}
 	else {
 		const bool showIt = CBTConfig::get(CBTConfig::logo);
