@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CRESMGR_H
 #define CRESMGR_H
@@ -371,6 +380,13 @@ namespace workspace {}
 				extern const char* actionName;
 			}
 
+			namespace findStrongs {
+				extern QString tooltip;
+
+				extern const QString icon;
+				extern const KShortcut accel;
+				extern const char* actionName;
+			}
 		}
 
 		namespace bibleWindow {
@@ -418,7 +434,7 @@ namespace workspace {}
 
 				extern const KShortcut accel;
 			}
-
+			
 			namespace copyMenu {
 				extern const QString icon;
 			}
